@@ -21,7 +21,7 @@ Sphinx::Search - Sphinx search engine API Perl client
 
 Please note that you *MUST* install a version which is compatible with your version of Sphinx.
 
-Use version 0.20 for Sphinx 0.9.9-rc2 and later (Please read the Compatibility Note under L<SetEncoders> regarding encoding changes)
+Use version 0.21 for Sphinx 0.9.9-rc2 and later (Please read the Compatibility Note under L<SetEncoders> regarding encoding changes)
 
 Use version 0.15 for Sphinx 0.9.9-svn-r1674
 
@@ -43,7 +43,7 @@ Use version 0.02 for Sphinx 0.9.8-cvs-20070818
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 =head1 SYNOPSIS
 
@@ -150,7 +150,7 @@ sub _sphPackI64 {
     my $v = shift;
 
     # x64 route
-    my $i = $self->{_longsize} >= 8 ? int($v) : Math::BigInt->new("$v");
+    my $i = $self->{_native64} ? int($v) : Math::BigInt->new("$v");
     return pack ( "NN", $i>>32, $i & 4294967295 );
 }
 
@@ -159,7 +159,7 @@ sub _sphPackU64 {
     my $self = shift;
     my $v = shift;
 
-    my $i = $self->{_longsize} >= 8  ? int($v) : Math::BigInt->new("$v");
+    my $i = $self->{_native64} ? int($v) : Math::BigInt->new("$v");
     return pack ( "NN", $i>>32, $i & 4294967295 );
 }
 
@@ -181,7 +181,7 @@ sub _sphUnpackU64
     my ($h,$l) = unpack ( "N*N*", $v );
 
     # x64 route
-    return ($h<<32) + $l if ( $self->{_longsize} >= 8 );
+    return ($h<<32) + $l if $self->{_native64};
 
     # x32 route, BigInt
     $h = Math::BigInt->new($h);
@@ -201,7 +201,7 @@ sub _sphUnpackI64
     my $neg = ($h & 0x80000000) ? 1 : 0;
 
     # x64 route
-    if ( $self->{_longsize} >= 8 ) {
+    if ( $self->{_native64} ) {
 	return -(~(($h<<32) + $l) + 1) if $neg;
 	return ($h<<32) + $l;
     }
@@ -297,7 +297,7 @@ sub new {
 	_reqs           => [],
 	_timeout        => 0,
 
-	_longsize      => $Config{longsize},
+	_native64      => $Config{longsize} == 8 || defined $Config{use64bitint},
 
 	_string_encoder => \&encode_utf8,
 	_string_decoder => \&decode_utf8,
